%% 
addpath /Users/pf/iscmodeling/gwinc/
ifo = IFOModel;
[ss,nn] = gwinc(5,5000,ifo,SourceModel,2);
ff = nn.Freq;

%% suspension thermal noise in gwinc is obsolete
%% use M Barton's mathematica model output

mbquadlite2lateral_20090819TM_TN;
tvec = sqrt(xvec.^2 + (1e-3*zvec).^2);
tvec = tvec*2;  % 4 masses
nn.SuspThermalB = interp1(fvec,tvec,ff,[],0);
nn.SuspThermalB = nn.SuspThermalB.^2/(4000^2);  % convert to strain

% recalculate the total
nn.Total = nn.ResGas + nn.SuspThermalB + nn.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;


hndls = loglog(ff,sqrt(nn.Quantum),'-',...         % Quantum Unification  
                 ff,sqrt(nn.Seismic),'-',...        % Seismic
                 ff,sqrt(nn.Newtonian),'-',...         % Gravity Gradients
                 ff,sqrt(nn.SuspThermalB),'-',...         % Suspension thermal
                 ff,sqrt(nn.MirrorThermal.CoatBrown),'-',...         % Coating Brownian
                 ff,sqrt(nn.MirrorThermal.CoatTO),'--',...       % Coating thermooptic
                 ff,sqrt(nn.MirrorThermal.SubBrown),'--',...        % Substrate brownian
                 ff,sqrt(nn.ResGas),'--',...        % Gas
                 ff,sqrt(nn.Total),'k');            % Total Noise
  set(hndls(1:(end)),'LineWidth',3);
  leggravg = strcat('Newtonian background(\beta=',num2str(ifo.Seismic.Beta),')');
  legpower = [num2str(ifo.Laser.Power,'%3.1f') ' W'];
  lh = legend('Quantum noise',...
         'Seismic noise',...
         'Gravity Gradients',...
         'Suspension thermal noise',...
         'Coating Brownian noise',...
         'Coating Thermo-optic noise',...
         'Substrate Brownian noise',...
         'Excess Gas',...
         'Total noise',...
         'Location','NorthEast');
  set(lh,'fontsize',14);
  xlabel('Frequency [Hz]','FontSize',16);
  ylabel('Strain [1/\surdHz]','FontSize',16);
  grid;
  axis([8 5000 3e-25 1e-21]);
  %title(['AdvLIGO Noise Curve: P_{in} = ' legpower],'FontSize',18)  
  
  clrtable=[0.7   0.0   0.9
            0.6   0.4   0.0
            0.0   0.8   0.0
            0.3   0.3   1.0
            1.0   0.2   0.1
            0.0   1.0   0.9
            1.0   0.7   0.0
            0.8   1.0   0.0
            1.0   0.0   0.0
            0.6   0.6   0.6];
  for gag = 1:(length(hndls) - 1)
    set(hndls(gag), 'color',clrtable(gag,:));
  end  
  set(hndls(end),'linewidth',5,'color',0.35*[1 1 1]);